@@ -2,12 +2,12 @@
 <context>
     <name>Cmd</name>
     <message>
-        <location filename="../cmd.cpp" line="141"/>
+        <location filename="../src/cmd.cpp" line="141"/>
         <source>Administrator Access Required</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../cmd.cpp" line="142"/>
+        <location filename="../src/cmd.cpp" line="142"/>
         <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
         <translation type="unfinished"/>
     </message>
@@ -15,18 +15,18 @@
 <context>
     <name>CustomDialog</name>
     <message>
-        <location filename="../dialog.cpp" line="16"/>
+        <location filename="../src/dialog.cpp" line="16"/>
         <source>Live environment detected. Please select the root partition of the
  system you want to modify (only Linux partitions are displayed)</source>
         <translation>Detectado sistema externo en execución. Seleccionar a partición do sistema a modificar (son exhibidas só particións Linux)</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="22"/>
+        <location filename="../src/dialog.cpp" line="22"/>
         <source>OK</source>
         <translation>Aceptar</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="23"/>
+        <location filename="../src/dialog.cpp" line="23"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
@@ -34,418 +34,423 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="33"/>
+        <location filename="../src/mainwindow.ui" line="33"/>
         <source>Options</source>
         <translation>Opcións</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="39"/>
+        <location filename="../src/mainwindow.ui" line="39"/>
         <source>Use simplified menu structure without submenus</source>
         <translation>Usar estrutura de menú simplificada, sen submenús</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="42"/>
+        <location filename="../src/mainwindow.ui" line="42"/>
         <source>Use flat menus (no submenus)</source>
         <translation>Usar menús simples (sen submenús)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="55"/>
+        <location filename="../src/mainwindow.ui" line="55"/>
         <source>Boot to</source>
         <translation>Arranque para</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="78"/>
+        <location filename="../src/mainwindow.ui" line="78"/>
         <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
         <translation>Establecer 0 para cargar de inmediato a escolla predeterminada sen exhibir o menú de opcións de arranque, ou -1 para manter o menú en espera</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="81"/>
+        <location filename="../src/mainwindow.ui" line="81"/>
         <source>Menu timeout</source>
         <translation>Tempo de espera</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="104"/>
+        <location filename="../src/mainwindow.ui" line="104"/>
         <source>Kernel parameters</source>
         <translation>Parámetros do núcleo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="117"/>
+        <location filename="../src/mainwindow.ui" line="117"/>
         <source>seconds</source>
         <translation>segundos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="124"/>
+        <location filename="../src/mainwindow.ui" line="124"/>
         <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
         <translation>Con está opción activada, a escolla de opción de arranque que for feita no GRUB será gardada como a nova predeterminada para os arranques futuros</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="127"/>
+        <location filename="../src/mainwindow.ui" line="127"/>
         <source>Enable saving last boot choice</source>
         <translation>Gardar a última escolla de arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="134"/>
+        <location filename="../src/mainwindow.ui" line="134"/>
         <source>Manage UEFI Boot Options</source>
         <translation>Xestionar opcións de arranque UEFI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="150"/>
+        <location filename="../src/mainwindow.ui" line="150"/>
         <source>Background</source>
         <translation>Imaxe de fondo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="168"/>
+        <location filename="../src/mainwindow.ui" line="168"/>
         <source>Image</source>
         <translation>Imaxe</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="181"/>
-        <location filename="../mainwindow.ui" line="283"/>
+        <location filename="../src/mainwindow.ui" line="181"/>
+        <location filename="../src/mainwindow.ui" line="283"/>
         <source>Enable theme</source>
         <translation>Activar tema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="261"/>
+        <location filename="../src/mainwindow.ui" line="261"/>
         <source>Splash</source>
         <translation>Máscara</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="296"/>
+        <location filename="../src/mainwindow.ui" line="296"/>
         <source>Preview</source>
         <translation>Visualizar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="319"/>
+        <location filename="../src/mainwindow.ui" line="319"/>
         <source>Messages</source>
         <translation>Mensaxes</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="325"/>
+        <location filename="../src/mainwindow.ui" line="325"/>
         <source>Very detailed</source>
         <translation>Presentación completa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="332"/>
+        <location filename="../src/mainwindow.ui" line="332"/>
         <source>Detailed (default setting)</source>
         <translation>Presentación normal (predeterminada)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="342"/>
+        <location filename="../src/mainwindow.ui" line="342"/>
         <source>Limited</source>
         <translation>Presentación limitada</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="358"/>
+        <location filename="../src/mainwindow.ui" line="358"/>
         <source>Display log</source>
         <translation>Amosar o rexistro</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="411"/>
+        <location filename="../src/mainwindow.ui" line="411"/>
         <source>Display help </source>
         <translation>Amosar axuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="414"/>
+        <location filename="../src/mainwindow.ui" line="414"/>
         <source>Help</source>
         <translation>Axuda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="421"/>
+        <location filename="../src/mainwindow.ui" line="421"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="453"/>
+        <location filename="../src/mainwindow.ui" line="453"/>
         <source>About this application</source>
         <translation>Sobre esta aplicación</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="456"/>
+        <location filename="../src/mainwindow.ui" line="456"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="463"/>
+        <location filename="../src/mainwindow.ui" line="463"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="498"/>
+        <location filename="../src/mainwindow.ui" line="498"/>
         <source>Quit application</source>
         <translation>Saír do aplicativo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="501"/>
+        <location filename="../src/mainwindow.ui" line="501"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="508"/>
+        <location filename="../src/mainwindow.ui" line="508"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="549"/>
+        <location filename="../src/mainwindow.ui" line="549"/>
         <source>Apply</source>
         <translation>Aplicar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="99"/>
+        <location filename="../src/mainwindow.cpp" line="99"/>
         <source>Still running</source>
         <translation>Aínda executándose</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="373"/>
-        <location filename="../mainwindow.cpp" line="381"/>
-        <location filename="../mainwindow.cpp" line="415"/>
-        <location filename="../mainwindow.cpp" line="526"/>
-        <location filename="../mainwindow.cpp" line="1346"/>
-        <location filename="../mainwindow.cpp" line="1359"/>
-        <location filename="../mainwindow.cpp" line="1365"/>
+        <location filename="../src/mainwindow.cpp" line="382"/>
+        <location filename="../src/mainwindow.cpp" line="390"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
+        <location filename="../src/mainwindow.cpp" line="535"/>
+        <location filename="../src/mainwindow.cpp" line="1359"/>
+        <location filename="../src/mainwindow.cpp" line="1372"/>
+        <location filename="../src/mainwindow.cpp" line="1378"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../src/mainwindow.cpp" line="371"/>
         <source>Installing bootsplash, please wait</source>
         <translation>Instalando máscara, agarde</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="369"/>
+        <location filename="../src/mainwindow.cpp" line="156"/>
+        <source>Preview is disabled because &apos;splash&apos; parameter is not present in kernel command line. To enable preview, add &apos;splash&apos; to boot parameters and reboot.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="378"/>
         <source>Updating sources</source>
         <translation>Actualizando as orixes</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="381"/>
+        <location filename="../src/mainwindow.cpp" line="390"/>
         <source>Could not install the bootsplash.</source>
         <translation>A máscara non foi instalada.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="526"/>
+        <location filename="../src/mainwindow.cpp" line="535"/>
         <source>Could not create a temporary folder</source>
         <translation>Non foi posíbel crear un cartafol temporal </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="535"/>
-        <location filename="../mainwindow.cpp" line="555"/>
+        <location filename="../src/mainwindow.cpp" line="544"/>
+        <location filename="../src/mainwindow.cpp" line="564"/>
         <source>Cannot continue</source>
         <translation>Imposible continuar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="535"/>
+        <location filename="../src/mainwindow.cpp" line="544"/>
         <source>Cannot open LUKS device. Exiting...</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="556"/>
+        <location filename="../src/mainwindow.cpp" line="565"/>
         <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
         <translation>Non é posible crear un ambiente chroot. Non é posible cambiar as opcións de arranque. Saíndo...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="887"/>
-        <location filename="../mainwindow.cpp" line="1266"/>
+        <location filename="../src/mainwindow.cpp" line="896"/>
+        <location filename="../src/mainwindow.cpp" line="1275"/>
         <source>Updating configuration, please wait</source>
         <translation>Actualizando a configuración, agarda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="958"/>
+        <location filename="../src/mainwindow.cpp" line="967"/>
         <source>Updating initramfs...</source>
         <translation>Actualizando o initramfs...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="972"/>
-        <location filename="../mainwindow.cpp" line="1281"/>
+        <location filename="../src/mainwindow.cpp" line="981"/>
+        <location filename="../src/mainwindow.cpp" line="1290"/>
         <source>Updating grub...</source>
         <translation>Actualizando o GRUB...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="997"/>
+        <location filename="../src/mainwindow.cpp" line="1006"/>
         <source>About %1</source>
         <translation>Sobre %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="998"/>
+        <location filename="../src/mainwindow.cpp" line="1007"/>
         <source>Version: </source>
         <translation>Versión</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1000"/>
+        <location filename="../src/mainwindow.cpp" line="1009"/>
         <source>Program for selecting common start-up choices</source>
         <translation>Programa para seleccionar opcións de iniciación comúns</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1002"/>
+        <location filename="../src/mainwindow.cpp" line="1011"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1003"/>
+        <location filename="../src/mainwindow.cpp" line="1012"/>
         <source>%1 License</source>
         <translation>Licenza de %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1024"/>
+        <location filename="../src/mainwindow.cpp" line="1033"/>
         <source>%1 Help</source>
         <translation>Axuda para %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1034"/>
-        <location filename="../mainwindow.cpp" line="1243"/>
+        <location filename="../src/mainwindow.cpp" line="1043"/>
+        <location filename="../src/mainwindow.cpp" line="1252"/>
         <source>Running in a Virtual Machine</source>
         <translation>Executándose nunha máquina virtual</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1035"/>
-        <location filename="../mainwindow.cpp" line="1244"/>
+        <location filename="../src/mainwindow.cpp" line="1044"/>
+        <location filename="../src/mainwindow.cpp" line="1253"/>
         <source>You current system is running in a Virtual Machine,
 Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
         <translation>O sistema está a ser executado nunha máquina virtual.
 A máscara do arranque Plymouth será executada con limitacións. Tamén non será posible previsualizar o tema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1042"/>
+        <location filename="../src/mainwindow.cpp" line="1051"/>
         <source>Plymouth packages not installed</source>
         <translation>Paquetes do Plymouth non instalados</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1043"/>
+        <location filename="../src/mainwindow.cpp" line="1052"/>
         <source>Plymouth packages are not currently installed.
 OK to go ahead and install them?</source>
         <translation>Os paquetes do Plymouth non están instalados.
 Continuar e instalar estes paquetes?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1069"/>
+        <location filename="../src/mainwindow.cpp" line="1078"/>
         <source>Images (*.png *.jpg *.jpeg *.tga)</source>
         <translation>Imaxes (*.png *.jpg *.jpeg *.tga)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1211"/>
+        <location filename="../src/mainwindow.cpp" line="1220"/>
         <source>Log not found</source>
         <translation>Rexistro non atopado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1211"/>
+        <location filename="../src/mainwindow.cpp" line="1220"/>
         <source>Could not find log at </source>
         <translation>Non foi atopado rexistro en</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1346"/>
+        <location filename="../src/mainwindow.cpp" line="1359"/>
         <source>Could not retrieve UUID for %1</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1354"/>
+        <location filename="../src/mainwindow.cpp" line="1367"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Introducir o contrasinal para desbloquear a partición encriptada %1:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1359"/>
+        <location filename="../src/mainwindow.cpp" line="1372"/>
         <source>Password entry cancelled or empty for %1</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1365"/>
+        <location filename="../src/mainwindow.cpp" line="1378"/>
         <source>Could not open %1 LUKS container</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1200"/>
+        <location filename="../src/mainwindow.cpp" line="1209"/>
         <source>&amp;Close</source>
         <translation>&amp;Cerrar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../src/mainwindow.cpp" line="100"/>
         <source>A process is still running. Do you really want to quit?</source>
         <translation>Aínda está en execución un proceso. Estás seguro de que queres saír?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="167"/>
+        <location filename="../src/mainwindow.cpp" line="176"/>
         <source>Live System Detected</source>
         <translation>Sistema Live detectado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="169"/>
+        <location filename="../src/mainwindow.cpp" line="178"/>
         <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
         <translation>Actualmente estás executando un sistema Live. Desexa modificar as opcións de arranque para o sistema Live ou para un sistema instalado?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../src/mainwindow.cpp" line="180"/>
         <source>Live System</source>
         <translation>Sistema Live</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="172"/>
+        <location filename="../src/mainwindow.cpp" line="181"/>
         <source>Installed System</source>
         <translation>Sistema Instalado</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="373"/>
+        <location filename="../src/mainwindow.cpp" line="382"/>
         <source>Failed to update package sources.</source>
         <translation>Produciuse un erro ao actualizar as fontes dos paquetes.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="377"/>
+        <location filename="../src/mainwindow.cpp" line="386"/>
         <source>Installing packages:</source>
         <translation>Instalando paquetes:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="387"/>
+        <location filename="../src/mainwindow.cpp" line="396"/>
         <source>Success</source>
         <translation>Con éxito</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="387"/>
+        <location filename="../src/mainwindow.cpp" line="396"/>
         <source>Bootsplash installed successfully.</source>
         <translation>Bootsplash instalouse correctamente.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="415"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
         <source>Failed to create temporary file.</source>
         <translation>Erro ao crear o ficheiro temporal.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="980"/>
+        <location filename="../src/mainwindow.cpp" line="989"/>
         <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
         <translation>Actualmente estás executando no modo Live coa opción &quot;toram&quot;. Lembra gardar o ficheiro de persistencia ou remasterizar, se non, perderase os cambios realizados.  </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="982"/>
+        <location filename="../src/mainwindow.cpp" line="991"/>
         <source>Your changes have been successfully applied.</source>
         <translation>Os teus cambios aplicáronse correctamente.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="983"/>
+        <location filename="../src/mainwindow.cpp" line="992"/>
         <source>Operation Complete</source>
         <translation>Operación completada</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1068"/>
+        <location filename="../src/mainwindow.cpp" line="1077"/>
         <source>Select image to display in bootloader</source>
         <translation>Seleccionar a imaxe de fondo do cargador do arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1192"/>
+        <location filename="../src/mainwindow.cpp" line="1201"/>
         <source>Boot Log</source>
         <translation>Rexistro de arranque</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1232"/>
+        <location filename="../src/mainwindow.cpp" line="1241"/>
         <source>Needs reboot</source>
         <translation>É necesario reiniciar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1233"/>
+        <location filename="../src/mainwindow.cpp" line="1242"/>
         <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
         <translation>Plymouth acabou de ser instalado. Pode ser necesario reiniciar para exhibir as previsualizacións</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1302"/>
+        <location filename="../src/mainwindow.cpp" line="1315"/>
         <source>Click to select theme</source>
         <translation>Premer para seleccionar o tema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1313"/>
+        <location filename="../src/mainwindow.cpp" line="1326"/>
         <source>Select GRUB theme</source>
         <translation>Seleccionar o tema do GRUB</translation>
     </message>
@@ -453,7 +458,7 @@ Continuar e instalar estes paquetes?</translation>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../main.cpp" line="54"/>
+        <location filename="../src/main.cpp" line="64"/>
         <source>Program for selecting common start-up choices</source>
         <translation>Programa para seleccionar opcións de iniciación comúns</translation>
     </message>
@@ -461,33 +466,33 @@ Continuar e instalar estes paquetes?</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="55"/>
+        <location filename="../src/about.cpp" line="54"/>
         <source>License</source>
         <translation>Licenza</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="56"/>
-        <location filename="../about.cpp" line="65"/>
+        <location filename="../src/about.cpp" line="55"/>
+        <location filename="../src/about.cpp" line="64"/>
         <source>Changelog</source>
         <translation>Rexistro dos cambios</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="57"/>
+        <location filename="../src/about.cpp" line="56"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="76"/>
+        <location filename="../src/about.cpp" line="75"/>
         <source>&amp;Close</source>
         <translation>&amp;Cerrar</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="82"/>
+        <location filename="../src/main.cpp" line="92"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="83"/>
+        <location filename="../src/main.cpp" line="93"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>O usuario parece ser root; para usar este programa, pechar a sesión e iniciar sesión como usuario normal.</translation>
     </message>
